# Grid Workbench

A Python-based data structure to hold an electric grid model.

Contains functionality to import and export data from PowerWorld Simulator using Easy Sim Auto.

More documentation in progress.